struct SubtreeSum;Trait Implementations
Sourceimpl LinkCutTreeSpec for SubtreeSum
impl LinkCutTreeSpec for SubtreeSum
Sourceconst ROOT_TO_NODE_TOP_DOWN: bool = false
const ROOT_TO_NODE_TOP_DOWN: bool = false
Whether splay must propagate from the auxiliary root before rotations.
type Value = u64
type Data = SubtreeSumData
fn new(value: Self::Value) -> Self::Data
fn value(data: &Self::Data) -> &Self::Value
fn value_mut(data: &mut Self::Data) -> &mut Self::Value
fn bottom_up(data: &mut Self::Data, children: [Option<&Self::Data>; 2])
fn reverse(_data: &mut Self::Data)
fn attach_virtual(parent: &mut Self::Data, child: &mut Self::Data)
fn detach_virtual(parent: &mut Self::Data, child: &mut Self::Data)
Sourceconst MODIFY_REQUIRES_ACCESS: bool = true
const MODIFY_REQUIRES_ACCESS: bool = true
Whether
modify must expose the node to update virtual subtree state.fn top_down(_data: &mut Self::Data, _children: [Option<&mut Self::Data>; 2])
Sourcefn transfer_path_parent(_old_root: &mut Self::Data, _new_root: &mut Self::Data)
fn transfer_path_parent(_old_root: &mut Self::Data, _new_root: &mut Self::Data)
Moves state associated with the same path-parent edge after a splay.
Sourceimpl LinkCutTreeSubtreeFold for SubtreeSum
impl LinkCutTreeSubtreeFold for SubtreeSum
Sourceimpl TopTreeSpec for SubtreeSum
impl TopTreeSpec for SubtreeSum
type Info = u64
type Point = (u64, u64)
type Path = (u64, u64, u64)
fn vertex(info: &Self::Info) -> Self::Path
fn add_vertex(point: &Self::Point, info: &Self::Info) -> Self::Path
fn add_edge(path: &Self::Path) -> Self::Point
fn rake(left: &Self::Point, right: &Self::Point) -> Self::Point
fn compress(left: &Self::Path, right: &Self::Path) -> Self::Path
fn reverse(_path: &mut Self::Path)